import requests as req
from bs4 import BeautifulSoup as bf


class Sport:
    header = {"User-Agent" : "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/107.0.0.0 Safari/537.36"}

    url = "https://www.sondakika.com/spor/"

    def title(self, limit: int=1):
        url = self.url
        header = self.header

        requ = req.get(url, headers=header).text
        sp = bf(requ, "html.parser")

        title = ""
        h = sp.find_all("a", {"class": "content"})
        n = 1
        for sport_title in h:
            if n <= limit:
                if limit == 1:
                    title += sport_title.span.text
                else:
                    title += sport_title.span.text+"\n"
            n+=1

        return title


    def about(self, limit: int=1):
        url = self.url
        header = self.header

        requ = req.get(url, headers=header).text
        sp = bf(requ, "html.parser")

        about = ""
        a = sp.find_all("p", {"class": "news-detail news-column"})
        n = 1
        for sport_about in a:
            if n <= limit:
                if limit == 1:
                    about += sport_about.text
                else:
                    about += sport_about.text+"\n"
            n+=1

        return about
    
    def img(self, limit: int=1):
        url = self.url
        header = self.header
        requ = req.get(url, headers=header).text
        sp = bf(requ, "html.parser")
        img = ""

        m = sp.find_all("a", {"class": "fr"})
        n = 1

        for sport_img in m:
            if n <= limit:
                if limit == 1:
                    img += sport_img.img["data-original"]
                else:
                    img += sport_img.img["data-original"]+"\n"
            n+=1
        
        return img


from setuptools import setup, find_packages

setup(
    name="haberpy",
    version="0.0.1",
    description="Son dakika haberleri çekebilmenize yarar.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="",
    author="Emre",
    author_email="rewoxirewo@gmail.com",
    license="MIT",
    #classifiers = [
    #"Programming Language :: Python :: 3",
    #"License :: OSI Approved :: MIT License",
    #"Operating System :: OS Independent",
    #],
    keywords=["haberpy","haberpython", "haber", "haber-python", "haber-py", "sondakika", "son-dakika"],
    packages=find_packages(),
    requires=["requests"]
)


# https://github.com/Meinos10

import requests as req
from bs4 import BeautifulSoup

class Haberler():
    header = {"User-Agent" : "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/107.0.0.0 Safari/537.36"}

    url = "https://www.sondakika.com/"
    


    def text(self, limit: int=1):
        url = self.url
        header = self.header
        requ = req.get(url, headers=header).text
        sp = BeautifulSoup(requ, "html.parser")
        text = ""
        h = sp.find_all("a", {"class": "active"})
        n = 1

        for haber in h:
            if n <= limit:
                text += haber.img["alt"]+"\n"
                n += 1
        return text

    def img(self, limit: int=1):
        url = self.url
        header = self.header
        requ = req.get(url, headers=header).text
        sp = BeautifulSoup(requ, "html.parser")
        img = ""
        h = sp.find_all("a", {"class": "active"})
        n = 1
        manset = 1
        for haber in h:
            if n <= limit:
                if manset == 1:
                    img += haber.img["src"]+"\n"
                else:
                    img += haber.img["data-original"]+"\n"
                n += 1
                manset += 1
        return img

    def text_and_img(self, limit: int=1):
        url = self.url
        header = self.header
        requ = req.get(url, headers=header).text
        sp = BeautifulSoup(requ, "html.parser")
        text = ""
        img = ""
        h = sp.find_all("a", {"class": "active"})
        n = 1
        manset = 1
        for haber in h:
            if n <= limit:
                text += haber.img["alt"]+"\n"
                if manset == 1:
                    img += haber.img["src"]+"\n"
                else:
                    img += haber.img["data-original"]+"\n"
                n += 1
                manset += 1
        return text, img

    